import click
import yaml
import logging.config

from .preprocess import preprocess_file


def setup_logging(debug=False):
    logging.config.dictConfig({
        'version': 1,
        'disable_existing_loggers': False,
        'formatters': {
            'brief': {
                'format': '%(levelname)s %(name)s: %(message)s'
            }
        },
        'handlers': {
            'console': {
                'class': 'logging.StreamHandler',
                'level': 'DEBUG' if debug else 'INFO',
                'formatter': 'brief',
            }
        },
        'root': {
            'handlers': ['console'],
            'level': 'DEBUG' if debug else 'INFO',
        }
    })


@click.group()
def cli():
    setup_logging(True)


@cli.command(help='Run the preprocess daemon, attaching to a Redis queue')
def daemon(ctx):
    click.echo(ctx['CONFIG'])


@cli.command(help='Run a single, one-off preprocessing')
@click.argument('file_path', type=str)
@click.option('--config-file', type=click.File('r'))
@click.option('--use-dir', type=str) # TODO: check dir
def preprocess(file_path, config_file=None, use_dir=None):
    config = yaml.load(config_file)
    preprocess_file(config, file_path, use_dir)


if __name__ == '__main__':
    cli()
